@@ -15,10 +15,14 @@ from functools import wraps
 from anyvc.common.workdir import WorkDir, StatedPath
 from ..exc import NotFoundError
 
-from mercurial.__version__ import version as hgversion
-# no support for hg <= 1.0.2
-if hgversion < '1.2':
-    raise ImportError('HG version too old, please update to a release >= 1.2')
+try:
+    import mercurial.util
+    hgversion = mercurial.util.version()
+    from mercurial.__version__ import version as hgversion
+    if hgversion < '1.3':
+        raise ImportError('HG version too old, please update to a release >= 1.3')
+except AttributeError:
+    raise ImportError('HG version too old, please update to a release >= 1.3')
 
 from mercurial import ui as hgui, hg, commands, util, cmdutil
 from mercurial.match import match, always
@@ -79,8 +83,12 @@ class Mercurial(WorkDir):
         pass #XXX unneded
 
     def create_from(self, source):
-        hg.clone(remoteui(self.ui, {}),
-                str(source), self.path.strpath)
+        if hasattr(hg, 'peer'):
+            hg.clone(remoteui(self.ui, {}), {},
+                    str(source), self.path.strpath)
+        else:
+            hg.clone(remoteui(self.ui, {}),
+                    str(source), self.path.strpath)
 
     def status(self, paths=(), *k, **kw):
         glob = '**' if kw.get('recursive') else '*'
@@ -170,5 +178,9 @@ class Mercurial(WorkDir):
                 *self.joined(paths))
 
 
+    @grab_output
+    def update(self, paths=None, revision=None):
+        assert paths is None
+        commands.update(self.ui, self.repo, rev=revision)
 
 
