@@ -1,3 +1,4 @@
+from __future__ import with_statement
 import os
 
 from anyvc.common.workdir import CommandBased, relative_to, WorkDirWithParser
@@ -26,6 +27,8 @@ class SubVersion(CommandBased):
 
 
     def create_from(self, source):
+        from urllib import quote
+        source = quote(str(source))
         call(['svn', 'co', 'file://%s' % source, self.path.strpath])
 
     state_map = {
