@@ -1,15 +1,13 @@
 import py.test
 from datetime import datetime
 
-def test_repo_create(mgr):
-    repo = mgr.make_repo('repo')
+
+def test_repo_create(repo):
     default_branch = repo.prepare_default_structure()
     assert len(repo) in (0,1)
 
-def test_repo_default_head(mgr):
-    if mgr.vc == 'subversion':
-        py.test.skip('default head won\'t matter for svn')
-    wd = mgr.create_wd('wd')
+@py.test.mark.feature('dvcs')
+def test_repo_default_head(wd):
     repo = wd.repository
     wd.put_files({'test.py': "import sys\nprint sys.platform" })
     wd.add(paths=['test.py'])
